==> qtjambi-webenginewidgets-5.15.15-sources.jar: io/qt/webengine/widgets/QWebEngineCertificateError.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QWebEngineCertificateError</p>
 */
public class QWebEngineCertificateError extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum QWebEngineCertificateError::Error</p>
     */
    public enum Error implements QtEnumerator {
        /**
         * <p>Representing QWebEngineCertificateError::SslPinnedKeyNotInCertificateChain</p>
         */
        SslPinnedKeyNotInCertificateChain(-150),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateCommonNameInvalid</p>
         */
        CertificateCommonNameInvalid(-200),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateDateInvalid</p>
         */
        CertificateDateInvalid(-201),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateAuthorityInvalid</p>
         */
        CertificateAuthorityInvalid(-202),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateContainsErrors</p>
         */
        CertificateContainsErrors(-203),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateNoRevocationMechanism</p>
         */
        CertificateNoRevocationMechanism(-204),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateUnableToCheckRevocation</p>
         */
        CertificateUnableToCheckRevocation(-205),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateRevoked</p>
         */
        CertificateRevoked(-206),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateInvalid</p>
         */
        CertificateInvalid(-207),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateWeakSignatureAlgorithm</p>
         */
        CertificateWeakSignatureAlgorithm(-208),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateNonUniqueName</p>
         */
        CertificateNonUniqueName(-210),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateWeakKey</p>
         */
        CertificateWeakKey(-211),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateNameConstraintViolation</p>
         */
        CertificateNameConstraintViolation(-212),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateValidityTooLong</p>
         */
        CertificateValidityTooLong(-213),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateTransparencyRequired</p>
         */
        CertificateTransparencyRequired(-214),
        /**
         * <p>Representing QWebEngineCertificateError::CertificateKnownInterceptionBlocked</p>
         */
        CertificateKnownInterceptionBlocked(-217);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Error(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Error resolve(int value) {
            switch (value) {
            case -150: return SslPinnedKeyNotInCertificateChain;
            case -200: return CertificateCommonNameInvalid;
            case -201: return CertificateDateInvalid;
            case -202: return CertificateAuthorityInvalid;
            case -203: return CertificateContainsErrors;
            case -204: return CertificateNoRevocationMechanism;
            case -205: return CertificateUnableToCheckRevocation;
            case -206: return CertificateRevoked;
            case -207: return CertificateInvalid;
            case -208: return CertificateWeakSignatureAlgorithm;
            case -210: return CertificateNonUniqueName;
            case -211: return CertificateWeakKey;
            case -212: return CertificateNameConstraintViolation;
            case -213: return CertificateValidityTooLong;
            case -214: return CertificateTransparencyRequired;
            case -217: return CertificateKnownInterceptionBlocked;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    public QWebEngineCertificateError(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, io.qt.webengine.widgets.QWebEngineCertificateError other);
    
    public QWebEngineCertificateError(int error, io.qt.core.@NonNull QUrl url, boolean overridable, java.lang.@NonNull String errorDescription){
        super((QPrivateConstructor)null);
        initialize_native(this, error, url, overridable, errorDescription);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, int error, io.qt.core.QUrl url, boolean overridable, java.lang.String errorDescription);
    
    @QtUninvokable
    public final boolean answered(){
        return answered_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean answered_native_constfct(long __this__nativeId);
    
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificateChain(){
        return certificateChain_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificateChain_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void defer(){
        defer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void defer_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean deferred(){
        return deferred_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean deferred_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineCertificateError.@NonNull Error error(){
        return io.qt.webengine.widgets.QWebEngineCertificateError.Error.resolve(error_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int error_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final java.lang.@NonNull String errorDescription(){
        return errorDescription_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String errorDescription_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void ignoreCertificateError(){
        ignoreCertificateError_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void ignoreCertificateError_native(long __this__nativeId);
    
    @QtUninvokable
    public final boolean isOverridable(){
        return isOverridable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOverridable_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError other){
        assign_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineCertificateError(long __this__nativeId, long other);
    
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError arg2){
        return operator_equal_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineCertificateError(long __this__nativeId, long arg2);
    
    @QtUninvokable
    public final void rejectCertificate(){
        rejectCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void rejectCertificate_native(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineCertificateError(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineCertificateError) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineCertificateError) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineCertificateError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineCertificateError clone_native(long __this_nativeId);
}

==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineCertificateError.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineCertificateError</code></p>
 */
public class QWebEngineCertificateError extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * <p>Java wrapper for Qt enum <code>QWebEngineCertificateError::Error</code></p>
     */
    public enum Error implements QtEnumerator {
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>SslPinnedKeyNotInCertificateChain</code></p>
         */
        SslPinnedKeyNotInCertificateChain(-150),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateCommonNameInvalid</code></p>
         */
        CertificateCommonNameInvalid(-200),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateDateInvalid</code></p>
         */
        CertificateDateInvalid(-201),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateAuthorityInvalid</code></p>
         */
        CertificateAuthorityInvalid(-202),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateContainsErrors</code></p>
         */
        CertificateContainsErrors(-203),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateNoRevocationMechanism</code></p>
         */
        CertificateNoRevocationMechanism(-204),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateUnableToCheckRevocation</code></p>
         */
        CertificateUnableToCheckRevocation(-205),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateRevoked</code></p>
         */
        CertificateRevoked(-206),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateInvalid</code></p>
         */
        CertificateInvalid(-207),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateWeakSignatureAlgorithm</code></p>
         */
        CertificateWeakSignatureAlgorithm(-208),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateNonUniqueName</code></p>
         */
        CertificateNonUniqueName(-210),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateWeakKey</code></p>
         */
        CertificateWeakKey(-211),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateNameConstraintViolation</code></p>
         */
        CertificateNameConstraintViolation(-212),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateValidityTooLong</code></p>
         */
        CertificateValidityTooLong(-213),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateTransparencyRequired</code></p>
         */
        CertificateTransparencyRequired(-214),
        /**
         * <p>Representing <code>QWebEngineCertificateError::<wbr>CertificateKnownInterceptionBlocked</code></p>
         */
        CertificateKnownInterceptionBlocked(-217);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private Error(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static @NonNull Error resolve(int value) {
            switch (value) {
            case -150: return SslPinnedKeyNotInCertificateChain;
            case -200: return CertificateCommonNameInvalid;
            case -201: return CertificateDateInvalid;
            case -202: return CertificateAuthorityInvalid;
            case -203: return CertificateContainsErrors;
            case -204: return CertificateNoRevocationMechanism;
            case -205: return CertificateUnableToCheckRevocation;
            case -206: return CertificateRevoked;
            case -207: return CertificateInvalid;
            case -208: return CertificateWeakSignatureAlgorithm;
            case -210: return CertificateNonUniqueName;
            case -211: return CertificateWeakKey;
            case -212: return CertificateNameConstraintViolation;
            case -213: return CertificateValidityTooLong;
            case -214: return CertificateTransparencyRequired;
            case -217: return CertificateKnownInterceptionBlocked;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>QWebEngineCertificateError(QWebEngineCertificateError)</code></p>
     */
    public QWebEngineCertificateError(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, io.qt.webengine.widgets.QWebEngineCertificateError other);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>QWebEngineCertificateError(int,<wbr>QUrl,<wbr>bool,<wbr>QString)</code></p>
     */
    public QWebEngineCertificateError(int error, io.qt.core.@NonNull QUrl url, boolean overridable, java.lang.@NonNull String errorDescription){
        super((QPrivateConstructor)null);
        initialize_native(this, error, url, overridable, errorDescription);
    }
    
    private native static void initialize_native(QWebEngineCertificateError instance, int error, io.qt.core.QUrl url, boolean overridable, java.lang.String errorDescription);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>answered()const</code></p>
     */
    @QtUninvokable
    public final boolean answered(){
        return answered_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean answered_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>certificateChain()const</code></p>
     */
    @SuppressWarnings({"exports"})
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.network.@NonNull QSslCertificate> certificateChain(){
        return certificateChain_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.network.QSslCertificate> certificateChain_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>defer()</code></p>
     */
    @QtUninvokable
    public final void defer(){
        defer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void defer_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>deferred()const</code></p>
     */
    @QtUninvokable
    public final boolean deferred(){
        return deferred_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean deferred_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>error()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.QWebEngineCertificateError.@NonNull Error error(){
        return io.qt.webengine.widgets.QWebEngineCertificateError.Error.resolve(error_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int error_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>errorDescription()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String errorDescription(){
        return errorDescription_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String errorDescription_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>ignoreCertificateError()</code></p>
     */
    @QtUninvokable
    public final void ignoreCertificateError(){
        ignoreCertificateError_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void ignoreCertificateError_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>isOverridable()const</code></p>
     */
    @QtUninvokable
    public final boolean isOverridable(){
        return isOverridable_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isOverridable_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>operator=(QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError other){
        assign_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineCertificateError(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr>QWebEngineCertificateError)</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.@NonNull QWebEngineCertificateError arg2){
        return operator_equal_native_cref_QWebEngineCertificateError(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineCertificateError(long __this__nativeId, long arg2);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>rejectCertificate()</code></p>
     */
    @QtUninvokable
    public final void rejectCertificate(){
        rejectCertificate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void rejectCertificate_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineCertificateError::<wbr>url()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineCertificateError(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineCertificateError,<wbr>QWebEngineCertificateError)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineCertificateError) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineCertificateError) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineCertificateError)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineCertificateError clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineCertificateError clone_native(long __this_nativeId);
}
